# react-gbajs

> GBA emulator on your React project - easy and powerful to use!

Just three steps to set up it ✨

1 - Apply `GbaProvider` provider
```jsx
import { GbaProvider } from 'react-gbajs'

const App = () => (
  <GbaProvider>
    ...
  </GbaProvider>
)
```

2 - Get `play` function from `GbaContext` and call it with the game ROM
```jsx
import { useContext } from 'react'
import { GbaContext } from 'react-gbajs'

const Component = () => {
  const {
    play,
  } = useContext(GbaContext)

  const onSomeHandle = () => {
    const gameRom = getGameRom()
    playGba(gameRom)
  }

  return (
    <SomeComponent startGame={onSomeHandle}>
  )
}
```

3 - And render the emulator using the default export

```js
import GBAEmulator from 'react-gbajs'

const Emulator = () => (
  <GBAEmulator volume={0} />
)
```

## How it works

This package is a wrapper React for [GBA.js](https://github.com/endrift/gbajs), with some improvements.

## Features

`GbaContext` exports the following properties:

### `play(newRomBufferMemory)`

Use this method to play the emulator, passing as its argument the game's ROM. Every time this function is called, it creates a new `GameBoyAdvance` instance, so all game progress is lost.

### `saveState()`

Return the serializable state of the emulator.

### `updateState({ restoreState, newRomBuffer })`

Use this function to passing `restoreState` to restore to a previous state saved using `saveState`. You can also pass `newRomBuffer` to reset the emulator and then load a new ROM. If both are passed, the emulator will be reset with the new ROM and then restored to the given state.

### `addFreezeAddress({ address: number, size: 8 | 16 | 32, value: number })`

Freeze an address with the given value.

### `removeFreezeAddress(address: number)

Remove the freeze value on the given address.

### `frozenAddresses()`

Return the list of the addresses frozen in the following format:

```ts
{
  [address in number]: { size: 8 | 16 | 32, value: number }
}
```

# Contribution

1 - Clone this repository

```
> git clone git@github.com:macabeus/react-gbajs.git
> cd react-gbajs
```

2 - Build and watch the project

```
> npm run start
```

3 - In another terminal window, go to the [`sample`](sample) project, then build and watch it

```
> cd sample
> npm run start
```

Finish! Now you can develop the package and test it in real-time 🎉
